"""SMS

This module contains actions for sending SMS messages using Twilio.

!!! danger "Remember"

    You must have a Twilio account to use the actions in this plugin.
"""
from twilio.rest import Client


def send_message(account_sid: str, auth_token: str, send_from: str, send_to: str, message: str) -> None:
    """Send an SMS using the Twilio SMS API.

??? info "Input"

    - __account_sid:__ the Twilio account SID

    - __auth_token:__ the Twilio API authentication token for the account

    - __send_from:__ the phone number to send the message from (_with_ country code)

    - __send_to:__ the phone number to send the message to (_with_ country code)

    - __message:__ the message to send

??? success "Output"

    Nothing is outputted by this action.

??? example
    ```YAML linenums="1"
    - twilio.sms.send_message:
        message: Hello from PPA!
        send_to: +441234567890
      load:
        account_sid: twilio_account_sid
        auth_token: twilio_auth_token
        send_from:  from_number
    ```

!!! warning "Supplying Sensitive Data"

    You should ___always___ use a PPA Vault integration to provide sensitive data to a plugin action.
    """
    Client(account_sid, auth_token).messages.create(body=message, from_=send_from, to=send_to)
